/**
 * @file
 * vuo.math.max.real node implementation.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"
#include <float.h>

const char *moduleName = "Find Maximum";
const char *moduleDescription = "Outputs the largest number in the list.  If the list is empty, outputs 0.";
const char *moduleKeywords[] = { "greater", ">", "greatest", "largest", "highest", "most", "more", "biggest", "top", "limit", "peak", "bound", "range" };
const unsigned int moduleVersion = 100;
const bool nodeIsInterface = false;

void nodeEvent
(
		VuoInputData(VuoList_VuoReal) numbers,
		VuoOutputData(VuoReal) max
)
{
	unsigned long termsCount = VuoListGetCount_VuoReal(numbers);

	if (!termsCount)
	{
		*max = 0;
		return;
	}

	*max = -DBL_MAX;
	for (unsigned long i = 0; i < termsCount; ++i)
	{
		double value = VuoListGetValueAtIndex_VuoReal(numbers, i);
		if (value > *max)
			*max = value;
	}
}
