/**
 * @file
 * vuo.math.min.integer node implementation.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"
#include <limits.h>

const char *moduleName = "Find Minimum";
const char *moduleDescription = "Outputs the smallest number in the list.  If the list is empty, outputs 0.";
const char *moduleKeywords[] = { "<", "smaller", "smallest", "lower", "lowest", "least", "less", "limit", "bound", "range" };
const unsigned int moduleVersion = 100;
const bool nodeIsInterface = false;

void nodeEvent
(
		VuoInputData(VuoList_VuoInteger) numbers,
		VuoOutputData(VuoInteger) min
)
{
	unsigned long termsCount = VuoListGetCount_VuoInteger(numbers);

	if (!termsCount)
	{
		*min = 0;
		return;
	}

	*min = LONG_MAX;
	for (unsigned long i = 0; i < termsCount; ++i)
	{
		signed long value = VuoListGetValueAtIndex_VuoInteger(numbers, i);
		if (value < *min)
			*min = value;
	}
}
